/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'format', 'ka', {
	label: 'ფიორმატირება',
	panelTitle: 'ფორმატირება',
	tag_address: 'მისამართი',
	tag_div: 'ჩვეულებრივი (DIV)',
	tag_h1: 'სათაური 1',
	tag_h2: 'სათაური 2',
	tag_h3: 'სათაური 3',
	tag_h4: 'სათაური 4',
	tag_h5: 'სათაური 5',
	tag_h6: 'სათაური 6',
	tag_p: 'ჩვეულებრივი',
	tag_pre: 'ფორმატირებული'
} );
