/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'basicstyles', 'sq', {
	bold: 'Trash',
	italic: 'Pjerrët',
	strike: 'Nëpërmes',
	subscript: 'Nën-skriptë',
	superscript: 'Super-skriptë',
	underline: 'Nënvijëzuar'
} );
