/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'list', 'ko', {
	bulletedlist: '순서 없는 목록',
	numberedlist: '순서 있는 목록'
} );
