/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'pastetext', 'fr', {
	button: 'Coller comme texte sans mise en forme',
	title: 'Coller comme texte sans mise en forme'
} );
