/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'specialchar', 'ko', {
	options: '특수문자 옵션',
	title: '특수문자 선택',
	toolbar: '특수문자 삽입'
} );
