/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'basicstyles', 'gl', {
	bold: 'Negra',
	italic: 'Cursiva',
	strike: 'Riscado',
	subscript: 'Subíndice',
	superscript: 'Superíndice',
	underline: 'Subliñado'
} );
