/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'about', 'sr', {
	copy: 'Copyright &copy; $1. All rights reserved.', // MISSING
	dlgTitle: 'About CKEditor', // MISSING
	help: 'Check $1 for help.', // MISSING
	moreInfo: 'For licensing information please visit our web site:', // MISSING
	title: 'About CKEditor', // MISSING
	userGuide: 'CKEditor User\'s Guide' // MISSING
} );
