/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'fakeobjects', 'fr', {
	anchor: 'Ancre',
	flash: 'Animation Flash',
	hiddenfield: 'Champ caché',
	iframe: 'IFrame',
	unknown: 'Objet inconnu'
} );
