/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'stylescombo', 'ku', {
	label: 'شێواز',
	panelTitle: 'شێوازی ڕازاندنەوە',
	panelTitle1: 'شێوازی خشت',
	panelTitle2: 'شێوازی ناوهێڵ',
	panelTitle3: 'شێوازی بەرکار'
} );
