/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'stylescombo', 'it', {
	label: 'Stili',
	panelTitle: 'Stili di formattazione',
	panelTitle1: 'Stili per blocchi',
	panelTitle2: 'Stili in linea',
	panelTitle3: 'Stili per oggetti'
} );
