/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'basicstyles', 'sl', {
	bold: 'Krepko',
	italic: 'Ležeče',
	strike: 'Prečrtano',
	subscript: 'Podpisano',
	superscript: 'Nadpisano',
	underline: 'Podčrtano'
} );
